@@ -28,3 +28,6 @@ link_files = {
         ],
     )
 }
+
+# Be strict about any broken references:
+nitpicky = True
